@@ -16,7 +16,7 @@ use Readonly;
 Readonly my $ENTRY_WIDTH_DATE     => 10;
 Readonly my $ENTRY_WIDTH_DATETIME => 19;
 
-our $VERSION = '2.10.2';
+our $VERSION = '2.11.2';
 my $EMPTY           = q{};
 my $DATE_FORMAT     = '%04d-%02d-%02d';
 my $DATETIME_FORMAT = '%04d-%02d-%02d %02d:%02d:%02d';
@@ -173,6 +173,13 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, properties => [
         'Hash of true type fonts available',                 # blurb
         [qw/readable writable/]                              # flags
     ),
+    Glib::ParamSpec->string(
+        'text_position',                                     # name
+        'Text position',                                     # nick
+        'Where to place the OCR output',                     # blurb
+        'behind',                                            # default
+        [qw/readable writable/]                              # flags
+    ),
     Glib::ParamSpec->string(
         'pdf-font',                                            # name
         'PDF font',                                            # nick
@@ -795,15 +802,10 @@ sub add_pdf_options {
             'lzw', __('LZW'),
             __('Compress output with Lempel-Ziv & Welch encoding.')
         ],
-        [ 'zip', __('Zip'), __('Compress output with deflate encoding.') ],
-        [
-            'packbits', __('Packbits'),
-            __('Compress output with Packbits encoding.')
-        ],
         [ 'g3', __('G3'), __('Compress output with CCITT Group 3 encoding.') ],
         [ 'g4', __('G4'), __('Compress output with CCITT Group 4 encoding.') ],
-        [ 'png',  __('PNG'),  __('Compress output with PNG encoding.') ],
-        [ 'jpg',  __('JPEG'), __('Compress output with JPEG encoding.') ],
+        [ 'png', __('Flate'), __('Compress output with flate encoding.') ],
+        [ 'jpg', __('JPEG'),  __('Compress output with JPEG (DCT) encoding.') ],
         [ 'none', __('None'), __('Use no compression algorithm on output.') ],
     );
 
@@ -837,6 +839,26 @@ sub add_pdf_options {
     );
     $hbox->pack_end( $combob, FALSE, FALSE, 0 );
 
+    my $hboxt = Gtk3::HBox->new;
+    $vboxp->pack_start( $hboxt, TRUE, TRUE, 0 );
+    $label = Gtk3::Label->new( __('Position of OCR output') );
+    $hboxt->pack_start( $label, FALSE, FALSE, 0 );
+    my @positions = (
+        [ 'behind', __('Behind'), __('Put OCR output behind image.') ],
+        [
+            'right', __('Right'),
+            __('Put OCR output to the right of the image.')
+        ],
+    );
+    my $combot = Gscan2pdf::ComboBoxText->new_from_array(@positions);
+    $combot->signal_connect(
+        changed => sub {
+            $self->set( 'text_position', $combot->get_active_index );
+        }
+    );
+    $combot->set_active_index( $self->get('text_position') );
+    $hboxt->pack_end( $combot, FALSE, FALSE, 0 );
+
     $self->add_font_button($vboxp);
 
     if ( $self->get('can-encrypt-pdf') ) {
