@@ -28,7 +28,7 @@ Readonly my $NOT_FOUND      => -1;
 my $uuid_object = Data::UUID->new;
 my $EMPTY       = q{};
 
-our $VERSION = '2.10.2';
+our $VERSION = '2.11.2';
 
 my ( $prog_name, $logger, %callback, $_self );
 
@@ -986,7 +986,7 @@ sub _write_buffer_to_fh {
         $image->{height} = $parm->{lines};
     }
     else {
-        $image->{height} = @{ $image->{data} } / $parm->{pixels_per_line};
+        $image->{height} = @{ $image->{data} } / $parm->{bytes_per_line};
         $image->{height} /= _number_frames($parm);
     }
     _thread_write_pnm_header( $fh, $parm->{format}, $parm->{pixels_per_line},
