@@ -34,7 +34,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.10.2';
+    $VERSION = '2.11.2';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -228,7 +228,7 @@ sub export_text {
 sub import_pdftotext {
     my ( $self, $html ) = @_;
     my $tree = Gscan2pdf::Bboxtree->new;
-    $tree->from_pdftotext( $html, $self->get_resolution );
+    $tree->from_pdftotext( $html, $self->get_resolution, $self->get_size );
     $self->{bboxtree} = $tree->json;
     return;
 }
